@@ -14,8 +14,8 @@ class SnortRule(models.Model):
     description = models.TextField(max_length=256)
     extra = models.TextField(max_length=256, blank=True)
     location = models.CharField(max_length=256)
-    request_ref = models.CharField(max_length=12, blank=True)
-    main_ref = models.CharField(max_length=12, blank=True)
+    document = models.CharField(max_length=12, blank=True)
+    treatment = models.CharField(max_length=12, blank=True)
     date = models.DateTimeField(auto_now=True)
     is_template = models.BooleanField(default=False)
     pcap_sanity_check = models.ManyToManyField("pcaps.Pcap", related_name='pcap_sanity_check', blank=True)
